LyricEntry class

Constructors

LyricEntry(String line, int position, int duration)

Properties

duration int
the duration of this line
final
hashCode int
The hash code for this object.
no setteroverride
line String
final
position int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeStamp String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

pattern RegExp
getter/setter pair

Static Methods

inflate(String line, Map<int, String> map) → void
build from a .lrc file line .such as: 11:44.100 what makes your beautiful