HtmlCode class

Constructors

HtmlCode()

Properties

b ↔ bool
getter/setter pair
fontColor ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
i ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
u ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited